@@ -4,9 +4,10 @@
    (TeX-add-to-alist 'LaTeX-provided-class-options
                      '(("article" "x11names" "english")))
    (TeX-add-to-alist 'LaTeX-provided-package-options
-                     '(("fontenc" "T1") ("inputenc" "utf8") ("natbib" "round") ("helvet" "scaled=0.92") ("mathpazo" "sc") ("enumitem" "shortlabels") ("Sweave" "noae" "inconsolata")))
+                     '(("fontenc" "T1") ("inputenc" "utf8") ("natbib" "round") ("helvet" "scaled=0.92") ("mathpazo" "sc") ("Sweave" "noae" "inconsolata") ("enumitem" "shortlabels")))
    (add-to-list 'LaTeX-verbatim-environments-local "Verbatim")
    (add-to-list 'LaTeX-verbatim-environments-local "lstlisting")
+   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "href")
    (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperref")
    (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperimage")
    (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperbaseurl")
@@ -26,23 +27,28 @@
     "microtype"
     "helvet"
     "mathpazo"
+    "Sweave"
     "booktabs"
     "enumitem"
-    "Sweave"
+    "framed"
     "xcolor"
     "hyperref")
    (TeX-add-symbols
-    '("samp" 1)
-    '("code" 1)
-    '("pkg" 1)
     '("mat" 1)
     '("VAR" 1)
     '("E" 1)
-    "LAS")
+    '("file" 1)
+    '("samp" 1)
+    '("code" 1)
+    '("pkg" 1)
+    "LAS"
+    "FrameCommand")
    (LaTeX-add-labels
     "sec:introduction"
     "sec:continuous"
     "tab:continuous"
+    "fig:diagram:fp-family"
+    "fig:diagram:trgamma-family"
     "sec:phase-type"
     "eq:Markov-transition-matrix"
     "eq:cdf-phtype"
@@ -50,6 +56,7 @@
     "sec:discrete"
     "tab:discrete"
     "eq:mixture"
+    "eq:mixture:alt"
     "sec:pig"
     "eq:pig:px"
     "eq:bessel_k"
@@ -62,9 +69,10 @@
     "eq:expint"
     "eq:betaint"
     "eq:betaint:2"
+    "sec:api"
     "sec:implementation"
     "sec:app:continuous"
-    "sec:app:continuous:transformed-beta"
+    "sec:app:continuous:feller-pareto"
     "sec:app:continuous:transformed-gamma"
     "sec:app:continuous:other"
     "sec:app:phase-type"
@@ -73,11 +81,6 @@
     "sec:app:discrete:zt"
     "sec:app:discrete:zm"
     "sec:app:discrete:pig")
-   (LaTeX-add-environments
-    '("texample" LaTeX-env-args ["argument"] 0)
-    '("exercice" LaTeX-env-args ["argument"] 0)
-    '("emphbox" LaTeX-env-args ["argument"] 1)
-    '("bibexample" LaTeX-env-args ["argument"] 0))
    (LaTeX-add-bibliographies
     "actuar")
    (LaTeX-add-xcolor-definecolors
